==> rvm_1.0.tar.gz: rvm-1.0/test-rconfig-006.cc <==
#include "config.h"

#include <iostream>
#include <string>
#include <cassert>

#ifdef HAVE_UNISTD_H
#include <unistd.h>
#endif

#include <errno.h>

#include "asserts.h"
#include "types.h"
#include "error.h"
#include "estring.h"
#include "fs.h"
#include "tstamp.h"
#include "rconfig.h"
#include "test-rconfig-setup.h"

// #define ERR_OUT(e) std::cerr << e;
#define ERR_OUT(e)

void test(void)
{
	char *argv[256] = { 0 };
	int argc = 0;
	bool thrown = false;

	argv[argc++] = "<program>";
	argv[argc++] = "--archive";

	config.default_file("./test-rconfig.dir/global-include.dir/file-7.conf");
	config.default_logdir("./test-rconfig.dir/log.dir");
	try {
		config.init(argc, argv);
	}
	catch(error e) {
		ERR_OUT(e);
		// assert(e.num() == 0);
		assert(!e.internal());
		assert(e.size() == 6);
		assert(e[0].what() == "No configuration file(s) found: \"../../nonexistent-file.conf\"");
		assert(e[1].what() == "At ./test-rconfig.dir/global-include.dir/file-7.dir/../file-7.dir/dir.2/file-7.3.4.conf[1]");
		assert(e[2].what() == "For files found matching: \"file-7.dir/dir.2/*\"");
		assert(e[3].what() == "At ./test-rconfig.dir/global-include.dir/file-7.dir/../file-7.2.conf[1]");
		assert(e[4].what() == "At ./test-rconfig.dir/global-include.dir/file-7.dir/file-7.1.conf[1]");
		assert(e[5].what() == "At ./test-rconfig.dir/global-include.dir/file-7.conf[1]");
		thrown = true;
	}
	catch(...) {
		assert(0);
	}
	assert(thrown);
}

int main(int argc, char *argv[])
{
	cleanup();
	setup();
	try {
		test();
	}
	catch(error e) {
		std::cerr << e;
		assert(0);
	}
	catch(...) {
		std::cerr << err_unknown;
		assert(0);
	}
	cleanup();
	return(0);
}

==> rvm_1.11.tar.gz: rvm-1.11/test-rconfig-006.cc <==
#include "config.h"

#include <iostream>
#include <string>
#include <cassert>

#ifdef HAVE_UNISTD_H
#include <unistd.h>
#endif

#include <errno.h>

#include "asserts.h"
#include "types.h"
#include "error.h"
#include "estring.h"
#include "fs.h"
#include "tstamp.h"
#include "rconfig.h"
#include "test-rconfig-setup.h"

// #define ERR_OUT(e) std::cerr << e;
#define ERR_OUT(e)

void test(void)
{
	char const * argv[256] = { 0 };
	int argc = 0;
	bool thrown = false;

	argv[argc++] = "<program>";
	argv[argc++] = "--archive";

	config.default_file("./test-rconfig.dir/global-include.dir/file-7.conf");
	config.default_logdir("./test-rconfig.dir/log.dir");
	try {
		config.init(argc, argv);
	}
	catch(error e) {
		ERR_OUT(e);
		// assert(e.num() == 0);
		assert(!e.internal());
		assert(e.size() == 6);
		assert(e[0].what() == "No configuration file(s) found: \"../../nonexistent-file.conf\"");
		assert(e[1].what() == "At ./test-rconfig.dir/global-include.dir/file-7.dir/../file-7.dir/dir.2/file-7.3.4.conf[1]");
		assert(e[2].what() == "For files found matching: \"file-7.dir/dir.2/*\"");
		assert(e[3].what() == "At ./test-rconfig.dir/global-include.dir/file-7.dir/../file-7.2.conf[1]");
		assert(e[4].what() == "At ./test-rconfig.dir/global-include.dir/file-7.dir/file-7.1.conf[1]");
		assert(e[5].what() == "At ./test-rconfig.dir/global-include.dir/file-7.conf[1]");
		thrown = true;
	}
	catch(...) {
		assert(0);
	}
	assert(thrown);
}

int main(int argc, char const * argv[])
{
	cleanup();
	setup();
	try {
		test();
	}
	catch(error e) {
		std::cerr << e;
		assert(0);
	}
	catch(...) {
		std::cerr << err_unknown;
		assert(0);
	}
	cleanup();
	return(0);
}
